# List of contract addresses

## Polygon (137)
| Name | Environment Variable | Address |
| ---- | -------------------- | ------- |
| `Service Registry L 2` | `CUSTOM_SERVICE_REGISTRY_ADDRESS` | [`0xE3607b00E75f6405248323A9417ff6b39B244b50`](https://polygonscan.com/address/0xE3607b00E75f6405248323A9417ff6b39B244b50) |
| `Service Manager` | `CUSTOM_SERVICE_MANAGER_ADDRESS` | [`0x3C1fF68f5aa342D296d4DEe4Bb1cACCA912D95fE`](https://polygonscan.com/address/0x3C1fF68f5aa342D296d4DEe4Bb1cACCA912D95fE) |
| `Service Registry Token Utility` | `CUSTOM_SERVICE_REGISTRY_TOKEN_UTILITY_ADDRESS` | [`0xa45E64d13A30a51b91ae0eb182e88a40e9b18eD8`](https://polygonscan.com/address/0xa45E64d13A30a51b91ae0eb182e88a40e9b18eD8) |
| `Service Manager Token` | `CUSTOM_SERVICE_MANAGER_ADDRESS` | [`0x04b0007b2aFb398015B76e5f22993a1fddF83644`](https://polygonscan.com/address/0x04b0007b2aFb398015B76e5f22993a1fddF83644) |
| `Gnosis Safe Multisig` | `CUSTOM_GNOSIS_SAFE_PROXY_FACTORY_ADDRESS` | [`0x3d77596beb0f130a4415df3D2D8232B3d3D31e44`](https://polygonscan.com/address/0x3d77596beb0f130a4415df3D2D8232B3d3D31e44) |
| `Gnosis Safe Same Address Multisig` | `CUSTOM_GNOSIS_SAFE_SAME_ADDRESS_MULTISIG_ADDRESS` | [`0xd8BCC126ff31d2582018715d5291A508530587b0`](https://polygonscan.com/address/0xd8BCC126ff31d2582018715d5291A508530587b0) |
| `Recovery Module` | `CUSTOM_RECOVERY_MODULE_ADDRESS` | [`0x02C26437B292D86c5F4F21bbCcE0771948274f84`](https://polygonscan.com/address/0x02C26437B292D86c5F4F21bbCcE0771948274f84) |
| `Safe Multisig With Recovery Module` | `CUSTOM_SAFE_MULTISIG_WITH_RECOVERY_MODULE_ADDRESS` | [`0x1a0bFCC27051BCcDDc444578f56A4F5920e0E083`](https://polygonscan.com/address/0x1a0bFCC27051BCcDDc444578f56A4F5920e0E083) |
| `Multisend` | `CUSTOM_MULTISEND_ADDRESS` | [`0x40A2aCCbd92BCA938b02010E17A5b8929b49130D`](https://polygonscan.com/address/0x40A2aCCbd92BCA938b02010E17A5b8929b49130D) |

## Gnosis (100)
| Name | Environment Variable | Address |
| ---- | -------------------- | ------- |
| `Service Registry L 2` | `CUSTOM_SERVICE_REGISTRY_ADDRESS` | [`0x9338b5153AE39BB89f50468E608eD9d764B755fD`](https://gnosisscan.io/address/0x9338b5153AE39BB89f50468E608eD9d764B755fD) |
| `Service Registry Token Utility` | `CUSTOM_SERVICE_REGISTRY_TOKEN_UTILITY_ADDRESS` | [`0xa45E64d13A30a51b91ae0eb182e88a40e9b18eD8`](https://gnosisscan.io/address/0xa45E64d13A30a51b91ae0eb182e88a40e9b18eD8) |
| `Service Manager Token` | `CUSTOM_SERVICE_MANAGER_ADDRESS` | [`0x04b0007b2aFb398015B76e5f22993a1fddF83644`](https://gnosisscan.io/address/0x04b0007b2aFb398015B76e5f22993a1fddF83644) |
| `Gnosis Safe Multisig` | `CUSTOM_GNOSIS_SAFE_PROXY_FACTORY_ADDRESS` | [`0x3C1fF68f5aa342D296d4DEe4Bb1cACCA912D95fE`](https://gnosisscan.io/address/0x3C1fF68f5aa342D296d4DEe4Bb1cACCA912D95fE) |
| `Gnosis Safe Same Address Multisig` | `CUSTOM_GNOSIS_SAFE_SAME_ADDRESS_MULTISIG_ADDRESS` | [`0x6e7f594f680f7aBad18b7a63de50F0FeE47dfD06`](https://gnosisscan.io/address/0x6e7f594f680f7aBad18b7a63de50F0FeE47dfD06) |
| `Recovery Module` | `CUSTOM_RECOVERY_MODULE_ADDRESS` | [`0x0Cb12457ed26d572c5e4A50f30b6f7A904662a72`](https://gnosisscan.io/address/0x0Cb12457ed26d572c5e4A50f30b6f7A904662a72) |
| `Safe Multisig With Recovery Module` | `CUSTOM_SAFE_MULTISIG_WITH_RECOVERY_MODULE_ADDRESS` | [`0xB4eB492bbfDcE5ccc11d675797cCF090eB0bCbd6`](https://gnosisscan.io/address/0xB4eB492bbfDcE5ccc11d675797cCF090eB0bCbd6) |
| `Multisend` | `CUSTOM_MULTISEND_ADDRESS` | [`0x40A2aCCbd92BCA938b02010E17A5b8929b49130D`](https://gnosisscan.io/address/0x40A2aCCbd92BCA938b02010E17A5b8929b49130D) |

## Arbitrum One (42161)
| Name | Environment Variable | Address |
| ---- | -------------------- | ------- |
| `Service Registry L 2` | `CUSTOM_SERVICE_REGISTRY_ADDRESS` | [`0xE3607b00E75f6405248323A9417ff6b39B244b50`](https://arbiscan.io/address/0xE3607b00E75f6405248323A9417ff6b39B244b50) |
| `Service Registry Token Utility` | `CUSTOM_SERVICE_REGISTRY_TOKEN_UTILITY_ADDRESS` | [`0x3d77596beb0f130a4415df3D2D8232B3d3D31e44`](https://arbiscan.io/address/0x3d77596beb0f130a4415df3D2D8232B3d3D31e44) |
| `Service Manager Token` | `CUSTOM_SERVICE_MANAGER_ADDRESS` | [`0x34C895f302D0b5cf52ec0Edd3945321EB0f83dd5`](https://arbiscan.io/address/0x34C895f302D0b5cf52ec0Edd3945321EB0f83dd5) |
| `Gnosis Safe Multisig` | `CUSTOM_GNOSIS_SAFE_PROXY_FACTORY_ADDRESS` | [`0x63e66d7ad413C01A7b49C7FF4e3Bb765C4E4bd1b`](https://arbiscan.io/address/0x63e66d7ad413C01A7b49C7FF4e3Bb765C4E4bd1b) |
| `Gnosis Safe Same Address Multisig` | `CUSTOM_GNOSIS_SAFE_SAME_ADDRESS_MULTISIG_ADDRESS` | [`0xBb7e1D6Cb6F243D6bdE81CE92a9f2aFF7Fbe7eac`](https://arbiscan.io/address/0xBb7e1D6Cb6F243D6bdE81CE92a9f2aFF7Fbe7eac) |
| `Recovery Module` | `CUSTOM_RECOVERY_MODULE_ADDRESS` | [`0xD0863340f947bE329c67e196e192705e53A1338f`](https://arbiscan.io/address/0xD0863340f947bE329c67e196e192705e53A1338f) |
| `Safe Multisig With Recovery Module` | `CUSTOM_SAFE_MULTISIG_WITH_RECOVERY_MODULE_ADDRESS` | [`0x17B2198872216D8469AdeBC1227D0d4824940821`](https://arbiscan.io/address/0x17B2198872216D8469AdeBC1227D0d4824940821) |
| `Multisend` | `CUSTOM_MULTISEND_ADDRESS` | [`0x40A2aCCbd92BCA938b02010E17A5b8929b49130D`](https://arbiscan.io/address/0x40A2aCCbd92BCA938b02010E17A5b8929b49130D) |

## Optimism (10)
| Name | Environment Variable | Address |
| ---- | -------------------- | ------- |
| `Service Registry L 2` | `CUSTOM_SERVICE_REGISTRY_ADDRESS` | [`0x3d77596beb0f130a4415df3D2D8232B3d3D31e44`](https://optimistic.etherscan.io/address/0x3d77596beb0f130a4415df3D2D8232B3d3D31e44) |
| `Service Registry Token Utility` | `CUSTOM_SERVICE_REGISTRY_TOKEN_UTILITY_ADDRESS` | [`0xBb7e1D6Cb6F243D6bdE81CE92a9f2aFF7Fbe7eac`](https://optimistic.etherscan.io/address/0xBb7e1D6Cb6F243D6bdE81CE92a9f2aFF7Fbe7eac) |
| `Service Manager Token` | `CUSTOM_SERVICE_MANAGER_ADDRESS` | [`0xFbBEc0C8b13B38a9aC0499694A69a10204c5E2aB`](https://optimistic.etherscan.io/address/0xFbBEc0C8b13B38a9aC0499694A69a10204c5E2aB) |
| `Gnosis Safe Multisig` | `CUSTOM_GNOSIS_SAFE_PROXY_FACTORY_ADDRESS` | [`0x5953f21495BD9aF1D78e87bb42AcCAA55C1e896C`](https://optimistic.etherscan.io/address/0x5953f21495BD9aF1D78e87bb42AcCAA55C1e896C) |
| `Gnosis Safe Same Address Multisig` | `CUSTOM_GNOSIS_SAFE_SAME_ADDRESS_MULTISIG_ADDRESS` | [`0xb09CcF0Dbf0C178806Aaee28956c74bd66d21f73`](https://optimistic.etherscan.io/address/0xb09CcF0Dbf0C178806Aaee28956c74bd66d21f73) |
| `Recovery Module` | `CUSTOM_RECOVERY_MODULE_ADDRESS` | [`0x6e7f594f680f7aBad18b7a63de50F0FeE47dfD06`](https://optimistic.etherscan.io/address/0x6e7f594f680f7aBad18b7a63de50F0FeE47dfD06) |
| `Safe Multisig With Recovery Module` | `CUSTOM_SAFE_MULTISIG_WITH_RECOVERY_MODULE_ADDRESS` | [`0x4be7A91e67be963806FeFA9C1FD6C53DfC358d94`](https://optimistic.etherscan.io/address/0x4be7A91e67be963806FeFA9C1FD6C53DfC358d94) |
| `Multisend` | `CUSTOM_MULTISEND_ADDRESS` | [`0x40A2aCCbd92BCA938b02010E17A5b8929b49130D`](https://optimistic.etherscan.io/address/0x40A2aCCbd92BCA938b02010E17A5b8929b49130D) |

## Base (8453)
| Name | Environment Variable | Address |
| ---- | -------------------- | ------- |
| `Service Registry L 2` | `CUSTOM_SERVICE_REGISTRY_ADDRESS` | [`0x3C1fF68f5aa342D296d4DEe4Bb1cACCA912D95fE`](https://basescan.org/address/0x3C1fF68f5aa342D296d4DEe4Bb1cACCA912D95fE) |
| `Service Registry Token Utility` | `CUSTOM_SERVICE_REGISTRY_TOKEN_UTILITY_ADDRESS` | [`0x34C895f302D0b5cf52ec0Edd3945321EB0f83dd5`](https://basescan.org/address/0x34C895f302D0b5cf52ec0Edd3945321EB0f83dd5) |
| `Service Manager Token` | `CUSTOM_SERVICE_MANAGER_ADDRESS` | [`0x63e66d7ad413C01A7b49C7FF4e3Bb765C4E4bd1b`](https://basescan.org/address/0x63e66d7ad413C01A7b49C7FF4e3Bb765C4E4bd1b) |
| `Gnosis Safe Multisig` | `CUSTOM_GNOSIS_SAFE_PROXY_FACTORY_ADDRESS` | [`0x22bE6fDcd3e29851B29b512F714C328A00A96B83`](https://basescan.org/address/0x22bE6fDcd3e29851B29b512F714C328A00A96B83) |
| `Gnosis Safe Same Address Multisig` | `CUSTOM_GNOSIS_SAFE_SAME_ADDRESS_MULTISIG_ADDRESS` | [`0xFbBEc0C8b13B38a9aC0499694A69a10204c5E2aB`](https://basescan.org/address/0xFbBEc0C8b13B38a9aC0499694A69a10204c5E2aB) |
| `Recovery Module` | `CUSTOM_RECOVERY_MODULE_ADDRESS` | [`0x359d53C326388D24037b3b1590d217fdb5EEE74c`](https://basescan.org/address/0x359d53C326388D24037b3b1590d217fdb5EEE74c) |
| `Safe Multisig With Recovery Module` | `CUSTOM_SAFE_MULTISIG_WITH_RECOVERY_MODULE_ADDRESS` | [`0x8c534420Db046d6801A1A8bE6fb602cC8F257453`](https://basescan.org/address/0x8c534420Db046d6801A1A8bE6fb602cC8F257453) |
| `Multisend` | `CUSTOM_MULTISEND_ADDRESS` | [`0x40A2aCCbd92BCA938b02010E17A5b8929b49130D`](https://basescan.org/address/0x40A2aCCbd92BCA938b02010E17A5b8929b49130D) |

## Celo (42220)
| Name | Environment Variable | Address |
| ---- | -------------------- | ------- |
| `Service Registry L 2` | `CUSTOM_SERVICE_REGISTRY_ADDRESS` | [`0xE3607b00E75f6405248323A9417ff6b39B244b50`](https://celoscan.io/address/0xE3607b00E75f6405248323A9417ff6b39B244b50) |
| `Service Registry Token Utility` | `CUSTOM_SERVICE_REGISTRY_TOKEN_UTILITY_ADDRESS` | [`0x3d77596beb0f130a4415df3D2D8232B3d3D31e44`](https://celoscan.io/address/0x3d77596beb0f130a4415df3D2D8232B3d3D31e44) |
| `Service Manager Token` | `CUSTOM_SERVICE_MANAGER_ADDRESS` | [`0x34C895f302D0b5cf52ec0Edd3945321EB0f83dd5`](https://celoscan.io/address/0x34C895f302D0b5cf52ec0Edd3945321EB0f83dd5) |
| `Gnosis Safe Multisig` | `CUSTOM_GNOSIS_SAFE_PROXY_FACTORY_ADDRESS` | [`0x63e66d7ad413C01A7b49C7FF4e3Bb765C4E4bd1b`](https://celoscan.io/address/0x63e66d7ad413C01A7b49C7FF4e3Bb765C4E4bd1b) |
| `Gnosis Safe Same Address Multisig` | `CUSTOM_GNOSIS_SAFE_SAME_ADDRESS_MULTISIG_ADDRESS` | [`0xBb7e1D6Cb6F243D6bdE81CE92a9f2aFF7Fbe7eac`](https://celoscan.io/address/0xBb7e1D6Cb6F243D6bdE81CE92a9f2aFF7Fbe7eac) |
| `Recovery Module` | `CUSTOM_RECOVERY_MODULE_ADDRESS` | [`0x24F792D51b398928459Dfbb4181bDb4D5d2CD472`](https://celoscan.io/address/0x24F792D51b398928459Dfbb4181bDb4D5d2CD472) |
| `Safe Multisig With Recovery Module` | `CUSTOM_SAFE_MULTISIG_WITH_RECOVERY_MODULE_ADDRESS` | [`0x379451B13e4900C7005Bf57467770b2EE4e62a86`](https://celoscan.io/address/0x379451B13e4900C7005Bf57467770b2EE4e62a86) |
| `Multisend` | `CUSTOM_MULTISEND_ADDRESS` | [`0x40A2aCCbd92BCA938b02010E17A5b8929b49130D`](https://celoscan.io/address/0x40A2aCCbd92BCA938b02010E17A5b8929b49130D) |

## Mode (34443)
| Name | Environment Variable | Address |
| ---- | -------------------- | ------- |
| `Service Registry L 2` | `CUSTOM_SERVICE_REGISTRY_ADDRESS` | [`0x3C1fF68f5aa342D296d4DEe4Bb1cACCA912D95fE`](https://modescan.io/address/0x3C1fF68f5aa342D296d4DEe4Bb1cACCA912D95fE) |
| `Service Registry Token Utility` | `CUSTOM_SERVICE_REGISTRY_TOKEN_UTILITY_ADDRESS` | [`0x34C895f302D0b5cf52ec0Edd3945321EB0f83dd5`](https://modescan.io/address/0x34C895f302D0b5cf52ec0Edd3945321EB0f83dd5) |
| `Service Manager Token` | `CUSTOM_SERVICE_MANAGER_ADDRESS` | [`0x63e66d7ad413C01A7b49C7FF4e3Bb765C4E4bd1b`](https://modescan.io/address/0x63e66d7ad413C01A7b49C7FF4e3Bb765C4E4bd1b) |
| `Gnosis Safe Multisig` | `CUSTOM_GNOSIS_SAFE_PROXY_FACTORY_ADDRESS` | [`0xBb7e1D6Cb6F243D6bdE81CE92a9f2aFF7Fbe7eac`](https://modescan.io/address/0xBb7e1D6Cb6F243D6bdE81CE92a9f2aFF7Fbe7eac) |
| `Gnosis Safe Same Address Multisig` | `CUSTOM_GNOSIS_SAFE_SAME_ADDRESS_MULTISIG_ADDRESS` | [`0xFbBEc0C8b13B38a9aC0499694A69a10204c5E2aB`](https://modescan.io/address/0xFbBEc0C8b13B38a9aC0499694A69a10204c5E2aB) |
| `Recovery Module` | `CUSTOM_RECOVERY_MODULE_ADDRESS` | [`0x1d79e0a600B61FAC1B8F40c27347e48962Ed2f23`](https://modescan.io/address/0x1d79e0a600B61FAC1B8F40c27347e48962Ed2f23) |
| `Safe Multisig With Recovery Module` | `CUSTOM_SAFE_MULTISIG_WITH_RECOVERY_MODULE_ADDRESS` | [`0x7Fd1F4b764fA41d19fe3f63C85d12bf64d2bbf68`](https://modescan.io/address/0x7Fd1F4b764fA41d19fe3f63C85d12bf64d2bbf68) |
| `Multisend` | `CUSTOM_MULTISEND_ADDRESS` | [`0x40A2aCCbd92BCA938b02010E17A5b8929b49130D`](https://modescan.io/address/0x40A2aCCbd92BCA938b02010E17A5b8929b49130D) |
